/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;

namespace VDS.Web.Consoles
{
    /// <summary>
    /// A server console which writes to the debug output
    /// </summary>
    public class DebugConsole
        : BaseConsole
    {
        protected override void PrintInformation(string message)
        {
            Debug.WriteLine(message);
        }

        protected override void PrintWarning(string message)
        {
            Debug.WriteLine(message);
        }

        protected override void PrintWarning(string message, Exception e)
        {
            this.PrintWarning(message + "\n" + this.GetFullStackTrace(e));
        }

        protected override void PrintError(string message)
        {
            Debug.WriteLine(message);
        }

        protected override void PrintError(string message, Exception e)
        {
            this.PrintError(message + "\n" + this.GetFullStackTrace(e));
        }

        /// <summary>
        /// Disposes of the console
        /// </summary>
        public override void Dispose()
        {
            //Nothing to dispose of
        }
    }
}
