/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;

namespace VDS.Web.Consoles
{
    /// <summary>
    /// A server console which writes to a file
    /// </summary>
    public class FileConsole
        : StreamConsole
    {
        /// <summary>
        /// Creates a new file console
        /// </summary>
        /// <param name="file">File</param>
        public FileConsole(String file)
            : base(FileConsole.OpenFileStream(file)) { }

        /// <summary>
        /// Helper method for setting up the file stream
        /// </summary>
        /// <param name="file">File</param>
        /// <returns>File stream</returns>
        private static Stream OpenFileStream(String file)
        {
            if (file == null) throw new ArgumentNullException("file", "File cannot be null");
            try
            {
                if (!File.Exists(file))
                {
                    return File.Create(file);
                }
                else
                {
                    return File.Open(file, FileMode.Append, FileAccess.Write);
                }
            }
            catch (Exception ex)
            {
                throw new ArgumentException("Unable to create/access the Log File '" + file + "'", "logFile", ex);
            }
        }
    }
}
