/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace VDS.Web.Consoles
{
    /// <summary>
    /// Interface for server consoles
    /// </summary>
    public interface IServerConsole
        : ILifecycleAwareComponent
    {
        /// <summary>
        /// Write an information message to the console
        /// </summary>
        /// <param name="message">Information message</param>
        void Information(String message);

        /// <summary>
        /// Writes a warning to the console
        /// </summary>
        /// <param name="message">Warning message</param>
        void Warning(String message);

        /// <summary>
        /// Writes a warning to the console
        /// </summary>
        /// <param name="message">Warning Message</param>
        /// <param name="e">Error that caused the warning to be issued</param>
        void Warning(String message, Exception e);

        /// <summary>
        /// Writes an error to the console
        /// </summary>
        /// <param name="message">Error Message</param>
        void Error(String message);

        /// <summary>
        /// Writes an error to the console
        /// </summary>
        /// <param name="message">Error Message</param>
        /// <param name="e">Error</param>
        void Error(String message, Exception e);

        /// <summary>
        /// Writes an error to the console
        /// </summary>
        /// <param name="e">Error</param>
        void Error(Exception e);
    }
}
