/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace VDS.Web.Consoles
{
    /// <summary>
    /// A console which wraps a set of consoles and sends requests to all wrapped consoles
    /// </summary>
    public class MulticastConsole
        : IServerConsole
    {
        private List<IServerConsole> _consoles = new List<IServerConsole>();

        public MulticastConsole()
            : this(Enumerable.Empty<IServerConsole>()) { }

        public MulticastConsole(IEnumerable<IServerConsole> consoles)
        {
            this._consoles.AddRange(consoles.Where(c => c != null));
        }

        public void AddConsole(IServerConsole console)
        {
            if (console == null) return;
            this._consoles.Add(console);
        }

        public void RemoveConsole(IServerConsole console)
        {
            if (console == null) return;
            this._consoles.Remove(console);
        }

        public IEnumerable<IServerConsole> Consoles
        {
            get
            {
                return this._consoles;
            }
        }

        public void ClearConsoles()
        {
            this._consoles.Clear();
        }

        public void Information(string message)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.Information(message);
            }
        }

        public void Warning(string message)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.Warning(message);
            }
        }

        public void Warning(string message, Exception e)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.Warning(message, e);
            }
        }

        public void Error(string message)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.Error(message);
            }
        }

        public void Error(string message, Exception e)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.Error(message, e);
            }
        }

        public void Error(Exception e)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.Error(e);
            }
        }

        public void PreStateChange(HttpServer server, ServerState target)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.PreStateChange(server, target);
            }
        }

        public void PostStateChange(HttpServer server)
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.PostStateChange(server);
            }
        }

        public void Dispose()
        {
            foreach (IServerConsole console in this._consoles)
            {
                console.Dispose();
            }
        }
    }
}
