/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;

namespace VDS.Web
{
    /// <summary>
    /// Represents arbitrary context information, essentially just a key value collection
    /// </summary>
    public class Context
    {
        private Dictionary<String, Object> _context = new Dictionary<string, object>();

        /// <summary>
        /// Gets/Sets an item in the state
        /// </summary>
        /// <param name="name">Key</param>
        /// <returns>Value or null if there is value associated with the given key</returns>
        public Object this[String name]
        {
            get
            {
                if (this._context.ContainsKey(name))
                {
                    return this._context[name];
                }
                else
                {
                    return null;
                }
            }
            set
            {
                lock (this._context)
                {
                    if (this._context.ContainsKey(name))
                    {
                        this._context[name] = value;
                    }
                    else
                    {
                        this._context.Add(name, value);
                    }
                }
            }
        }

        /// <summary>
        /// Gets the number of key value pairs in the context
        /// </summary>
        public int Count
        {
            get
            {
                return this._context.Count;
            }
        }

        /// <summary>
        /// Clears the context
        /// </summary>
        public void Clear()
        {
            this._context.Clear();
        }
    }
}
