/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Xml;
using System.Xml.Schema;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using VDS.Web.Logging;
using VDS.Web.Consoles;

namespace VDS.Web.Configuration
{
    [TestClass]
    public class ServerConfigurationTests
    {
        [TestMethod]
        public void ConfigValidation1()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example1.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigValidation2()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example2.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigValidation3()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example3.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigValidation4()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example4.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }
       
        [TestMethod]
        public void ConfigValidation5()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example5.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigValidation6()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example6.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigValidationExampleConfig()
        {
            using (Stream stream = File.OpenRead("server.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod, ExpectedException(typeof(XmlSchemaValidationException))]
        public void ConfigValidationInvalid1()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.invalid1.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod, ExpectedException(typeof(XmlSchemaValidationException))]
        public void ConfigValidationInvalid2()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.invalid2.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod, ExpectedException(typeof(XmlSchemaValidationException))]
        public void ConfigValidationInvalid3()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.invalid3.config"))
            {
                Assert.IsNotNull(stream);
                ServerConfiguration.Validate(stream);

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigApply1()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example1.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);
                
                String path = "/subdir/file.txt";
                Assert.IsNotNull(server.VirtualDirectories.GetDirectory(path, out path));
                Assert.AreEqual("file.txt", path);
                Assert.IsNotNull(server.MimeTypes.GetMapping(".test"));
                Assert.AreEqual("application/test", server.MimeTypes.GetMapping(".test").MimeType);
                
                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigApply2()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example2.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);

                List<IHttpLogger> loggers = server.Loggers.ToList();
                Assert.IsTrue(loggers.OfType<FileLogger>().Any());
                Assert.IsTrue(loggers.OfType<ConsoleLogger>().Any());
                Assert.IsTrue(loggers.OfType<EventLogger>().Any());

                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigApply3()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example3.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);

                Assert.IsInstanceOfType(server.Console, typeof(MulticastConsole));

                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigApply4()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example4.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);

                Assert.IsInstanceOfType(server.Console, typeof(MulticastConsole));
                MulticastConsole console = server.Console as MulticastConsole;
                Assert.AreEqual(1, console.Consoles.Count());
                Assert.IsInstanceOfType(console.Consoles.First(), typeof(MulticastConsole));

                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod, ExpectedException(typeof(HttpServerException))]
        public void ConfigApply5()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example5.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);
                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod]
        public void ConfigApply6()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.example6.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);

                Assert.IsInstanceOfType(server.Console, typeof(NullConsole));

                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod, ExpectedException(typeof(HttpServerException))]
        public void ConfigApplyInvalid1()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.invalid1.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);
                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod, ExpectedException(typeof(HttpServerException))]
        public void ConfigApplyInvalid2()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.invalid2.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);
                server.Dispose();

                if (stream != null) stream.Close();
            }
        }

        [TestMethod, ExpectedException(typeof(HttpServerException))]
        public void ConfigApplyInvalid3()
        {
            using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("VDS.Web.Configuration.Examples.invalid3.config"))
            {
                Assert.IsNotNull(stream);
                XmlDocument doc = new XmlDocument();
                doc.Load(stream);

                HttpServer server = new HttpServer(PortManager.GetNextPort());
                ServerConfiguration.Configure(server, doc);
                server.Dispose();

                if (stream != null) stream.Close();
            }
        }
    }
}
