/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using VDS.Web.Handlers;

namespace VDS.Web
{
    [TestClass]
    public class ErrorHandlingTests
    {
        private readonly int TestPort = PortManager.GetNextPort();

        private HttpServer _server;

        [TestInitialize]
        public void Setup()
        {
            HttpListenerHandlerCollection handlers = new HttpListenerHandlerCollection();
            handlers.AddMapping(new HttpRequestMapping(HttpRequestMapping.AllVerbs, HttpRequestMapping.AnyPath, typeof(ThrowErrorHandler)));
            this._server = new HttpServer(TestPort, handlers);
            this._server.Start();
        }

        [TestCleanup]
        public void Teardown()
        {
            this._server.Dispose();
        }

        private String ServerUrl
        {
            get
            {
                return "http://localhost:" + TestPort + "/test";
            }
        }

        [TestMethod]
        public void ErrorHandling1()
        {
            HttpWebRequest request = (HttpWebRequest)WebRequest.Create(this.ServerUrl);
            request.Timeout = 2500;
            try
            {
                using (HttpWebResponse response = (HttpWebResponse)request.GetResponse())
                {
                    response.Close();
                }
                Assert.Fail("Expected a HTTP 500 Response");
            }
            catch (WebException webEx)
            {
                Assert.IsNotNull(webEx.Response);
                Assert.AreEqual(HttpStatusCode.InternalServerError, ((HttpWebResponse)webEx.Response).StatusCode);

                using (StreamReader reader = new StreamReader(webEx.Response.GetResponseStream()))
                {
                    while (!reader.EndOfStream)
                    {
                        Console.WriteLine(reader.ReadLine());
                    }
                }
            }
        }
    }
}
