/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;

namespace VDS.Web.Handlers
{
    /// <summary>
    /// Handler for testing that simply generates data by echoing the given data the requested number of times
    /// </summary>
    public class GenerateDataHandler
        : IHttpListenerHandler
    {
        /// <summary>
        /// Returns that the handler is reusable
        /// </summary>
        public bool IsReusable
        {
            get
            {
                return true;
            }
        }

        /// <summary>
        /// Processes a request by echoing the given data the requested number of times
        /// </summary>
        /// <param name="context">HTTP Context</param>
        public void ProcessRequest(HttpServerContext context)
        {
            String data = context.Request.QueryString["data"];
            int repeats = 1;
            Int32.TryParse(context.Request.QueryString["repeats"], out repeats);
            if (repeats < 1) repeats = 1;
            bool unsafeMode = false;
            Boolean.TryParse(context.Request.QueryString["unsafe"], out unsafeMode);

            if (!unsafeMode)
            {
                using (StreamWriter writer = new StreamWriter(context.Response.OutputStream))
                {
                    for (int i = 1; i <= repeats; i++)
                    {
                        writer.Write(data);
                    }
                }
            }
            else
            {
                StreamWriter writer = new StreamWriter(context.Response.OutputStream);
                for (int i = 1; i <= repeats; i++)
                {
                    writer.Write(data);
                }
            }
        }
    }
}
