/*
VDS.Web.Server is licensed under the MIT License

Copyright (c) 2010-2013 Robert Vesse

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software 
is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using VDS.Web.Handlers;

namespace VDS.Web.Handlers
{
    /// <summary>
    /// A simple handler which responds with 200 OK to all requests but provides properties by which the properties of the request may be inspected
    /// </summary>
    class RequestInfoHandler
        : IHttpListenerHandler
    {
        public bool IsReusable
        {
            get 
            {
                return true;
            }
        }

        public HttpServerContext Context { get; private set; }

        public String HttpMethod { get; private set; }

        public FormVariables Form { get; private set; }

        public void ProcessRequest(HttpServerContext context)
        {
            this.Context = context;
            this.HttpMethod = context.Request.HttpMethod;
            this.Form = new FormVariables(context);

            context.Response.StatusCode = 200;
        }

        public void Reset()
        {
            this.Context = null;
            this.HttpMethod = null;
            this.Form = null;
        }

    }
}
